Data (pylira.data)
==================
This subpackage contains builtin datasets for testing and documentation.

.. automodapi:: pylira.data
    :no-heading:
    :no-inheritance-diagram:
    :include-all-objects:
